@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /****************************************************************
@@ -36,9 +36,11 @@
 #include "matrix.h"
 #include "cursors.h"
 #include "next_image.h"
+#include "gliv-image.h"
 
 extern rt_struct *rt;
 extern options_struct *options;
+extern GlivImage *current_image;
 extern GtkWidget *gl_widget;
 
 /* Left button saved position in the root window. */
@@ -47,29 +49,24 @@ static gfloat old1_root_x, old1_root_y;
 /* Where the left button press occurred in the window. */
 static gfloat press1_win_x, press1_win_y;
 
+/* Where the middle button press occurred in the window. */
+static gfloat press2_win_x, press2_win_y;
+
 /* Right button saved position in the window. */
 static gint old3_win_x, old3_win_y;
 
 /* If the middle button is released. */
 static gboolean mouse_wheel_zoom = TRUE;
 
-/* Number of times the pointer warped in each direction. */
-static gint nb_scr_w = 0, nb_scr_h = 0;
-
-/* Absolute position, taking into account the screen warpings. */
-#define ROOT_X(e) ((e)->x_root + nb_scr_w * rt->scr_width)
-#define ROOT_Y(e) ((e)->y_root + nb_scr_h * rt->scr_height)
-
 static gboolean button_press_event(GtkWidget * unused, GdkEventButton * event)
 {
+    if (current_image == NULL)
+        return FALSE;
+
     switch (event->button) {
     case 1:
-        /* Reset mouse warping. */
-        nb_scr_w = 0;
-        nb_scr_h = 0;
-
-        old1_root_x = ROOT_X(event);
-        old1_root_y = ROOT_Y(event);
+        old1_root_x = event->x_root;
+        old1_root_y = event->y_root;
 
         press1_win_x = event->x;
         press1_win_y = event->y;
@@ -77,6 +74,8 @@ static gboolean button_press_event(GtkWidget * unused, GdkEventButton * event)
 
     case 2:
         mouse_wheel_zoom = FALSE;
+        press2_win_x = event->x;
+        press2_win_y = event->y;
         break;
 
     case 3:
@@ -89,19 +88,41 @@ static gboolean button_press_event(GtkWidget * unused, GdkEventButton * event)
     return FALSE;
 }
 
+#define CHANGE_IMAGE_SCREEN_RATIO 20
+
+static void detect_image_change(GdkEventButton * event)
+{
+    int dx = event->x - press2_win_x;
+    int dy = event->y - press2_win_y;
+    int dir = 0;
+
+    if (!(event->state & GDK_CONTROL_MASK))
+        return;
+
+    if (dx > rt->scr_width / CHANGE_IMAGE_SCREEN_RATIO ||
+        dy > rt->scr_height / CHANGE_IMAGE_SCREEN_RATIO)
+        dir = 1;
+    else if (-dx > rt->scr_width / CHANGE_IMAGE_SCREEN_RATIO ||
+             -dy > rt->scr_height / CHANGE_IMAGE_SCREEN_RATIO)
+        dir = -1;
+
+    if (dir)
+        load_direction(dir);
+}
+
 static gboolean button_release_event(GtkWidget * unused, GdkEventButton * event)
 {
+    if (current_image == NULL)
+        return FALSE;
+
     switch (event->button) {
     case 1:
-        /* Reset mouse warping. */
-        nb_scr_w = 0;
-        nb_scr_h = 0;
-
         refresh(APPEND_HISTORY);
         break;
 
     case 2:
         mouse_wheel_zoom = TRUE;
+        detect_image_change(event);
         break;
 
     case 3:
@@ -118,12 +139,10 @@ static gboolean warp_pointer(gfloat x, gfloat y)
     gint new_x, new_y;
 
     if (x <= 0.0) {
-        nb_scr_w--;
         new_x = rt->scr_width - 1;
         warped = TRUE;
 
     } else if (x >= rt->scr_width - 1.0) {
-        nb_scr_w++;
         new_x = 0;
         warped = TRUE;
 
@@ -133,12 +152,10 @@ static gboolean warp_pointer(gfloat x, gfloat y)
     }
 
     if (y <= 0.0) {
-        nb_scr_h--;
         new_y = rt->scr_height - 1;
         warped = TRUE;
 
     } else if (y >= rt->scr_height - 1.0) {
-        nb_scr_h++;
         new_y = 0;
         warped = TRUE;
 
@@ -157,16 +174,16 @@ static gboolean warp_pointer(gfloat x, gfloat y)
  */
 static void update_coordinates1(GdkEventMotion * event)
 {
-    old1_root_x = ROOT_X(event);
-    old1_root_y = ROOT_Y(event);
+    old1_root_x = event->x_root;
+    old1_root_y = event->y_root;
 }
 
 static gint process_move(GdkEventMotion * event)
 {
     gfloat root_x, root_y;
 
-    root_x = ROOT_X(event);
-    root_y = ROOT_Y(event);
+    root_x = event->x_root;
+    root_y = event->y_root;
 
     matrix_move(root_x - old1_root_x, root_y - old1_root_y);
 
@@ -189,8 +206,8 @@ static gint process_rotation(GdkEventMotion * event)
     y0 = old1_root_y - center_y;
 
     /* Second rotation vector. */
-    x1 = ROOT_X(event) - center_x;
-    y1 = ROOT_Y(event) - center_y;
+    x1 = event->x_root - center_x;
+    y1 = event->y_root - center_y;
 
     angle = atan2f(y0, x0) + atan2f(x1, y1) - PI / 2.0;
 
@@ -203,7 +220,7 @@ static gint process_zoom(GdkEventMotion * event)
 {
     gfloat center_x, center_y, delta, ratio;
 
-    delta = ROOT_Y(event) - old1_root_y;
+    delta = event->y_root - old1_root_y;
     ratio = powf(ZOOM_FACTOR, delta / 10.0);
 
     if (options->zoom_pointer) {
@@ -228,6 +245,7 @@ static gboolean motion_notify_event(GtkWidget * unused, GdkEventMotion * event)
     if (skip) {
         /* We come just after a move_pointer(). */
         skip = FALSE;
+        update_coordinates1(event);
         return TRUE;
     }
 
@@ -236,6 +254,9 @@ static gboolean motion_notify_event(GtkWidget * unused, GdkEventMotion * event)
     else
         schedule_hide_cursor();
 
+    if (current_image == NULL)
+        return FALSE;
+
     if (event->state & GDK_BUTTON1_MASK) {
 
         if (event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) {
@@ -311,6 +332,9 @@ static gboolean process_arrow_key(GdkEventKey * event, gboolean press)
     guint arrow;
     gfloat x, y, angle;
 
+    if (current_image == NULL)
+        return FALSE;
+
     switch (event->keyval) {
     case GDK_Up:
     case GDK_KP_Up:
@@ -401,6 +425,9 @@ static gboolean key_release_event(GtkWidget * unused, GdkEventKey * event)
 
 static gboolean scroll_event(GtkWidget * unused, GdkEventScroll * event)
 {
+    if (current_image == NULL)
+        return FALSE;
+
     if (mouse_wheel_zoom) {
 
         if (event->direction == GDK_SCROLL_UP)
