@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /********************
@@ -559,7 +559,7 @@ static void file_error(const gchar * filename)
 {
     if (rt) {
         gchar *message = g_strconcat(filename, ": ", g_strerror(errno), NULL);
-        DIALOG_MSG(message);
+        DIALOG_MSG("%s", message);
         g_free(message);
     }
 }
@@ -634,8 +634,10 @@ gint serialize_collection_nogui(const gchar * filename)
     }
 
     tty = get_terminal_output();
-    fprintf(tty, _("Saving collection: %s"), filename_to_utf8(filename));
-    putc('\n', tty);
+    if (tty != NULL) {
+        fprintf(tty, _("Saving collection: %s"), filename_to_utf8(filename));
+        putc('\n', tty);
+    }
 
     res = save_collection(file, &cancel);
 
@@ -1041,8 +1043,10 @@ gint load_dot_gliv(const gchar * filename)
     loader_t loader;
 
     tty = get_terminal_output();
-    fprintf(tty, _("Loading collection: %s"), filename_to_utf8(filename));
-    putc('\n', tty);
+    if (tty != NULL) {
+        fprintf(tty, _("Loading collection: %s"), filename_to_utf8(filename));
+        putc('\n', tty);
+    }
 
     loader = get_loader(filename);
     if (loader == LOADER_DECOMP_DOT_GLIV)
