@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /*****************************
@@ -152,8 +152,7 @@ gboolean set_correct_cursor(void)
 
     if (new_cursor != current_type) {
         current_type = new_cursor;
-        if (rt->cursor_hidden == FALSE)
-            gdk_window_set_cursor(gl_widget->window, cursors[current_type]);
+        show_cursor();
     }
 
     return FALSE;
