@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /******************
@@ -53,9 +53,7 @@ static GList *files_list = NULL;
 static gint list_length = 0;
 static GList *list_end = NULL;
 static DECLARE_TIMESTAMP(timestamp);    /* Last modification. */
-
-/* The node to delete when no longer displayed. */
-static GList *to_destroy_node = NULL;
+static GList *obsolete_nodes = NULL;    /* Nodes to delete when possible */
 
 gint get_list_length(void)
 {
@@ -281,6 +279,7 @@ void remove_from_list(GList * node)
     if (current_image && current_image->node == node)
         current_image->node = NULL;
 
+    unload(node);
     g_free(node->data);
     files_list = g_list_delete_link(files_list, node);
     list_length--;
@@ -501,7 +500,7 @@ gboolean confirm_remove_current(void)
                           filename_to_utf8(filename));
 
     if (show_remove_dialog(msg)) {
-        to_destroy_node = current_image->node;
+        add_obsolete_node(current_image->node);
 
         if (remove(filename) < 0)
             perror(filename);
@@ -511,20 +510,6 @@ gboolean confirm_remove_current(void)
     return FALSE;
 }
 
-/* Called when the displayed image is changed. */
-gboolean delete_selected_image(void)
-{
-    if (to_destroy_node == NULL)
-        /* Nothing to destroy. */
-        return FALSE;
-
-    unload(to_destroy_node);
-    remove_from_list(to_destroy_node);
-
-    to_destroy_node = NULL;
-    return TRUE;
-}
-
 timestamp_t get_list_timestamp(void)
 {
     return timestamp;
@@ -579,3 +564,28 @@ GList *find_node_by_name(const gchar * name)
 
     return NULL;
 }
+
+void add_obsolete_node(GList * node)
+{
+    obsolete_nodes = g_list_prepend(obsolete_nodes, node);
+}
+
+gboolean remove_obsolete_nodes(void)
+{
+    GList *ptr, *next;
+    gboolean destroyed = FALSE;
+
+    for (ptr = obsolete_nodes; ptr != NULL; ptr = next) {
+        next = ptr->next;
+        if (ptr->data != current_image->node) {
+            remove_from_list(ptr->data);
+            obsolete_nodes = g_list_delete_link(obsolete_nodes, ptr);
+            destroyed = TRUE;
+        }
+    }
+
+    if (destroyed)
+        touch(&timestamp);
+
+    return destroyed;
+}
