@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.0.1 */
+/* ANSI-C code produced by gperf version 3.0.3 */
 /* Command-line: gperf -n --multiple-iterations 64 --output formats.c ../tools/formats.gperf  */
 /* Computed positions: -k'1-4' */
 
@@ -146,6 +146,9 @@ hash (register const char *str, register unsigned int len)
 
 #ifdef __GNUC__
 __inline
+#ifdef __GNUC_STDC_INLINE__
+__attribute__ ((__gnu_inline__))
+#endif
 #endif
 const struct format *
 ext_to_loader (register const char *str, register unsigned int len)
