@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /***********************************************
@@ -162,8 +162,7 @@ static gboolean drag_data_received(GtkWidget * unused1,
 
     ok = TRUE;
     nb_inserted = insert_after_current(uris, i, FALSE, TRUE);
-    if (nb_inserted > 0)
-        open_next_image(nb_inserted == 1);
+    new_images(nb_inserted);
 
   out_strfreev:
     g_strfreev(uris);
@@ -230,7 +229,7 @@ static void get_max_texture_size(void)
 
         message = g_strconcat(texture,
                               _("GL_MAX_TEXTURE_SIZE must be >= 64"), NULL);
-        DIALOG_MSG(message);
+        DIALOG_MSG("%s", message);
 
         g_free(texture);
         g_free(message);
@@ -250,8 +249,6 @@ static gboolean make_current(void)
 
 static gboolean first_expose(void)
 {
-    GlivImage *first_image;
-
     /* We only handle the first one. */
     g_signal_handlers_disconnect_by_func(gl_widget, G_CALLBACK(first_expose),
                                          NULL);
@@ -297,21 +294,7 @@ static gboolean first_expose(void)
     dnd_init();
 
     gtk_widget_queue_draw(GTK_WIDGET(get_current_window()));
-
-    first_image = load_first_image();
-    if (first_image != NULL) {
-        if (options->fullscreen == FALSE && options->resize_win == FALSE)
-            goto_window(first_image, TRUE);
-
-        g_object_unref(first_image);
-
-    } else if (options->fullscreen == FALSE)
-        goto_window(NULL, TRUE);
-
-    load_second_image();
-
-    if (options->build_menus)
-        do_later(G_PRIORITY_LOW, (GSourceDummyMarshal) rebuild_images_menus);
+    do_later(G_PRIORITY_LOW, load_first_image);
 
     return FALSE;
 }
@@ -346,9 +329,9 @@ void create_gl_widget(void)
         quit(1);
     }
 
-    gtk_widget_set_events(gl_widget,
-                          GDK_BUTTON_PRESS_MASK | GDK_BUTTON1_MOTION_MASK |
-                          GDK_BUTTON3_MOTION_MASK | GDK_BUTTON_RELEASE_MASK);
+    gtk_widget_add_events(gl_widget,
+                          GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK |
+                          GDK_BUTTON_RELEASE_MASK);
 
     if (options->delay != 0)
         gtk_widget_add_events(gl_widget, GDK_POINTER_MOTION_MASK);
