@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /************************************
@@ -401,8 +401,10 @@ GNode *get_tree(void)
             return TRUE;                                                     \
                                                                              \
         tree = get_tree();                                                   \
-        if (tree == NULL)                                                    \
-            return FALSE;                                                    \
+        if (tree == NULL) {                                                  \
+            touch(&timestamp);                                               \
+            return TRUE;                                                     \
+        }                                                                    \
                                                                              \
         gtk_widget_set_sensitive(GTK_WIDGET(cancel_menu_item), TRUE);        \
         reset_mnemonics();                                                   \
