@@ -4,6 +4,6 @@
 #include "gliv.h"
 
 GdkPixbuf *load_compressed_pixbuf(const gchar * filename, GError ** error);
-gint load_compressed_collection(const gchar * filename, gboolean in_the_head);
+gint load_compressed_collection(const gchar * filename);
 
 #endif
