@@ -18,10 +18,11 @@ gint init_list(gchar ** names, gint nb, gboolean sort, gboolean shuffle,
 gint insert_after_current(gchar ** names, gint nb, gboolean just_file,
                           gboolean add_all);
 gboolean confirm_remove_current(void);
-gboolean delete_selected_image(void);
 timestamp_t get_list_timestamp(void);
 const gchar *get_nth_filename(gint n);
 gint get_image_number(GlivImage * im);
 GList *find_node_by_name(const gchar * name);
+void add_obsolete_node(GList *node);
+gboolean remove_obsolete_nodes(void);
 
 #endif
