@@ -4,6 +4,6 @@
 #include "gliv.h"
 
 gboolean start_server(void);
-gboolean connect_server(void);
+gboolean connect_server(gboolean clear_list);
 
 #endif
