@@ -7,7 +7,7 @@
 
 void start_quiet(void);
 void stop_quiet(void);
-gboolean is_loading(void);
+const gchar *currently_loading(void);
 void install_segv_handler(void);
 void fill_ident(GlivImage * im);
 const gchar *get_extension(const gchar * filename);
@@ -15,6 +15,6 @@ loader_t get_loader(const gchar * filename);
 void set_loading(const gchar * filename);
 gint pixels_size(GdkPixbuf * pixbuf);
 GlivImage *make_gliv_image(GdkPixbuf * pixbuf);
-GlivImage *load_file(const gchar * filename);
+GlivImage *load_file(const gchar * filename, GError ** error);
 
 #endif
