@@ -2,9 +2,7 @@
 #define MAIN_H
 
 #include "gliv.h"
-#include "cmdline.h"
 
-gboolean get_on_off(const gchar * str);
 G_GNUC_NORETURN void quit(gint code);
 gboolean gui_quit(void);
 
