@@ -55,6 +55,10 @@
 #define powf pow
 #endif
 
+#ifndef HAVE_LOG10F
+#define log10f log10
+#endif
+
 /* Instead of finding it in a system or glib header. */
 #define PI 3.1415926535897932384626433832795029F
 
