@@ -17,6 +17,7 @@ G_GNUC_PURE gboolean is_matrix_symmetry(void);
 G_GNUC_PURE gboolean get_matrix_has_changed(void);
 G_GNUC_PURE gboolean is_filtering_needed(void);
 gboolean matrix_set_max_zoom(gint width, gint height, gboolean do_it);
+void matrix_fit(gboolean fit_w, gboolean fit_h);
 void matrix_reset(void);
 void matrix_rotate(gfloat angle);
 void matrix_move(gfloat x, gfloat y);
@@ -24,7 +25,7 @@ void matrix_zoom(gfloat ratio, gfloat x, gfloat y);
 void flip_matrix(gfloat * mat, gboolean h_flip);
 void matrix_flip_h(void);
 void matrix_flip_v(void);
-void matrix_set_top_left(void);
+void matrix_set_initial_position(void);
 void configure_matrix(GlivImage * im);
 gfloat *new_matrix(void);
 gfloat *get_matrix_for_image(GlivImage * im);
