@@ -7,6 +7,9 @@
 void after_reorder(void);
 const gchar *get_image_notice(void);
 void load_direction(gint dir);
+void load_random_image(void);
+void load_1st_image(void);
+void load_last_image(void);
 void load_first_image(void);
 void reload_current_image(void);
 void reload_images(void);
