@@ -3,7 +3,7 @@
 
 #include "gliv.h"
 
-gboolean menu_open(void);
+gboolean menu_open(gboolean select_dir);
 gboolean menu_image_nr(void);
 
 #endif
