@@ -16,6 +16,8 @@
 void draw_current_image(void);
 void render(void);
 void zoom_in(gfloat ratio);
+gint diff_timeval_us(GTimeVal * after, GTimeVal * before);
+gint get_fps_limiter_delay(GTimeVal * previous_frame);
 void refresh(gint what);
 void update_current_image_status(gboolean find_number);
 void do_later(gint priority, GSourceDummyMarshal func);
