@@ -2,15 +2,7 @@
 #define TEXTURE_MAP_H
 
 #include "gliv.h"
-
-/* Infos that can be freed once the map is created. */
-typedef struct {
-    gint width;
-    gint height;
-    gint x_tiles;
-    gint y_tiles;
-    GdkPixbuf *pixbuf;
-} loading_data;
+#include "tiling.h"
 
 /* A rectangle in a map. */
 typedef struct {
@@ -26,7 +18,11 @@ typedef struct {
     tile_dim *tiles;
     guint *tex_ids;
     guint list;
-    loading_data *map_init;
+    gint width;
+    gint height;
+    struct tiles *x_tiles;
+    struct tiles *y_tiles;
+    GdkPixbuf *pixbuf;
 } texture_map;
 
 #endif
