@@ -17,7 +17,7 @@ gboolean canceled_using_tree(void);
 gboolean more_recent_than_tree(timestamp_t ts);
 GNode *make_tree(void);
 void destroy_tree(GNode * tree);
-gint tree_count_files(GNode * tree);
+gint tree_count_files(void);
 void invalidate_last_tree(void);
 
 #endif
