@@ -12,9 +12,11 @@ gboolean toggle_menu_bar(void);
 gboolean toggle_status_bar(void);
 void update_status_bar(void);
 void create_windows(void);
-void goto_window(GlivImage * im, gboolean force);
+void goto_window(GlivImage * im, gboolean first_time);
 void toggle_fullscreen(gboolean enable);
 void update_window_title(void);
 GtkWindow *get_current_window(void);
+GtkWindow *new_window(const gchar * title);
+gboolean toggle_floating_windows(void);
 
 #endif
