@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /***********************************
@@ -36,6 +36,7 @@
 #include "params.h"
 #include "files_list.h"
 #include "textures.h"
+#include "math_floats.h"
 #include "thread.h"
 #include "decompression.h"
 #include "thumbnails.h"
@@ -321,6 +322,45 @@ G_GNUC_PURE static gint nb_maps(gint dim)
     return ret;
 }
 
+static void parse_exif_orientation(GdkPixbuf * pixbuf, GlivImage *im)
+{
+    const gchar *orientation_str = gdk_pixbuf_get_option(pixbuf, "orientation");
+
+    if (orientation_str)
+        switch (orientation_str[0]) {
+            case '2':
+                im->initial_angle = PI;
+                im->initial_h_flip = TRUE;
+                break;
+
+            case '3':
+                im->initial_angle = PI;
+                break;
+
+            case '4':
+                im->initial_h_flip = TRUE;
+                break;
+
+            case '5':
+                im->initial_angle = PI / 2.0;
+                im->initial_h_flip = TRUE;
+                break;
+
+            case '6':
+                im->initial_angle = -PI / 2.0;
+                break;
+
+            case '7':
+                im->initial_angle = -PI / 2.0;
+                im->initial_h_flip = TRUE;
+                break;
+
+            case '8':
+                im->initial_angle = PI / 2.0;
+                break;
+        }
+}
+
 GlivImage *make_gliv_image(GdkPixbuf * pixbuf)
 {
     GlivImage *im;
@@ -334,6 +374,7 @@ GlivImage *make_gliv_image(GdkPixbuf * pixbuf)
     im->width = gdk_pixbuf_get_width(pixbuf);
     im->height = gdk_pixbuf_get_height(pixbuf);
     im->has_alpha = gdk_pixbuf_get_has_alpha(pixbuf);
+    parse_exif_orientation(pixbuf, im);
 
     if (options->mipmap) {
         gint nb_w = nb_maps(im->width);
