@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /********************
@@ -37,6 +37,7 @@
 #include "ipc.h"
 #include "collection.h"
 #include "opengl.h"
+#include "mnemonics.h"
 
 rt_struct *rt;
 options_struct *options;
@@ -88,7 +89,7 @@ static void fill_options(struct gengetopt_args_info *ggo)
 { ggo->build_menus_given,  &options->build_menus,  ggo->build_menus_arg,  1 },
 { ggo->slide_show_given,   &options->start_show,   ggo->slide_show_arg,   0 },
 { ggo->add_all_given,      &option_add_all,        ggo->add_all_arg,      0 },
-{ FALSE,                   NULL,                   NULL,                    }
+{ FALSE,                   NULL,                   NULL,                  0 }
 /* *INDENT-ON* */
     };
 
@@ -163,7 +164,8 @@ static init_res init_args(gint argc, gchar ** argv, gboolean gtk_initialized)
     if (ggo == NULL)
         return res;
 
-    if (!ggo->collection_given && !gtk_initialized)
+    if (!ggo->collection_given && !FLAG_ON(ggo->client) &&
+        !FLAG_ON(ggo->client_clear) && !gtk_initialized)
         /*
          * We want a "graphical" gliv, so init it after gtk
          * to be able to show the progress dialog when loading collections.
@@ -211,12 +213,25 @@ static init_res init_args(gint argc, gchar ** argv, gboolean gtk_initialized)
             res = INIT_NO_IMAGES;
     }
 
-    if (ggo->collection_given)
+    if (ggo->collection_given) {
+        options->save_quit = FALSE;
         quit(serialize_collection_nogui(ggo->collection_arg));
+    }
 
-    if (FLAG_ON(ggo->client) && connect_server())
-        /* Successfully reused a GLiv window. */
-        quit(0);
+    if (FLAG_ON(ggo->client) || FLAG_ON(ggo->client_clear)) {
+        options->save_quit = FALSE;
+        if (FLAG_ON(ggo->client) && FLAG_ON(ggo->client_clear)) {
+            g_printerr(_("The --client and --client-clear command line options"
+                         " are mutually exclusive\n"));
+            quit(1);
+        }
+
+        if (connect_server(FLAG_ON(ggo->client_clear)))
+            /* Successfully reused a GLiv window. */
+            quit(0);
+    }
+
+    options->initial_geometry = g_strdup(ggo->geometry_arg);
 
   end:
     cmdline_parser_free(ggo);
@@ -232,10 +247,34 @@ G_GNUC_NORETURN void quit(gint code)
     exit(code);
 }
 
+static GtkCheckButton *get_stop_confirm_button(void)
+{
+    GtkCheckButton *confirm;
+    gchar *message;
+
+    if (options->save_quit)
+        message = g_strdup(_("Do not ask again"));
+    else
+        message =
+            g_strconcat(_("Do not ask again"),
+                        " (", _("Options will be saved"), ")", NULL);
+
+    confirm =
+        GTK_CHECK_BUTTON(gtk_check_button_new_with_mnemonic
+                         (add_mnemonic(message)));
+
+    gtk_widget_show_all(GTK_WIDGET(confirm));
+    g_free(message);
+
+    return confirm;
+}
+
 gboolean gui_quit(void)
 {
     GtkMessageDialog *dialog;
+    GtkCheckButton *stop_confirm;
     gchar *msg;
+    gint response;
 
     if (options->confirm_quit == FALSE)
         quit(0);
@@ -248,14 +287,25 @@ gboolean gui_quit(void)
                                                        GTK_BUTTONS_YES_NO,
                                                        "%s", msg));
 
+    stop_confirm = get_stop_confirm_button();
+    gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),
+                      GTK_WIDGET(stop_confirm));
+
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_YES);
 
-    set_hide_cursor_enabled(FALSE);
-    if (run_modal_dialog(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES)
+    response = run_modal_dialog(GTK_DIALOG(dialog));
+
+    if (response == GTK_RESPONSE_YES) {
+        options->confirm_quit =
+            !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(stop_confirm));
+
+        if (!options->confirm_quit && !options->save_quit)
+            save_rc(options);
+
         quit(0);
+    }
 
     gtk_widget_destroy(GTK_WIDGET(dialog));
-    set_hide_cursor_enabled(TRUE);
     return TRUE;
 }
 
