@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /***************
@@ -49,8 +49,10 @@
 #include "actions.h"
 #include "tree.h"
 #include "tree_browser.h"
+#include "gliv-image.h"
 
 extern options_struct *options;
+extern GlivImage *current_image;
 extern GtkMenuBar *menu_bar;
 
 void set_menu_label(GtkMenuItem * item, const gchar * text, gboolean mnemonic)
@@ -158,6 +160,9 @@ static gboolean menu_maximize(gint what)
 {
     gboolean old_maximize, old_scale_down;
 
+    if (current_image == NULL)
+        return FALSE;
+
     old_maximize = options->maximize;
     old_scale_down = options->scaledown;
 
@@ -203,6 +208,9 @@ enum transfo {
 
 static gboolean menu_transfo(enum transfo transfo)
 {
+    if (current_image == NULL)
+        return FALSE;
+
     switch (transfo) {
     case TRANSFO_CENTER:
     case TRANSFO_TOP_LEFT:
@@ -407,6 +415,9 @@ GtkAccelGroup *create_menus(void)
     ADD_MENU_ITEM(N_("Load previous image"), load_direction, GDK_p, -1);
     ADD_MENU_ITEM(N_("Load next image"), load_direction, GDK_n, 1);
     ADD_MENU_ITEM(N_("Load the Nth image..."), menu_image_nr, GDK_g, 0);
+    ADD_MENU_ITEM(N_("Load first image"), load_1st_image, GDK_comma, 0);
+    ADD_MENU_ITEM(N_("Load last image"), load_last_image, GDK_period, 0);
+    ADD_MENU_ITEM(N_("Load random image"), load_random_image, GDK_x, 0);
     ADD_MENU_ITEM(N_("Reload the current image"), reload_current_image, 0, 0);
     SEPARATOR;                  /* ------------------------------------ */
     ADD_MENU_ITEM(N_("Sort images list"), reorder_files, 0, FALSE);
