@@ -4,7 +4,7 @@
 
 #include <gdk/gdkx.h>
 
-void move_pointer(gint dest_x, gint dest_y);
+#include "move_pointer.h"
 
 #define EVENT_MASK Button1MotionMask | Button4MotionMask | ButtonMotionMask  | \
                    Button2MotionMask | Button5MotionMask | PointerMotionMask | \
