@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /****************************
@@ -27,6 +27,7 @@
 #include <time.h>               /* time_t */
 #include <stdio.h>              /* perror() */
 #include <string.h>             /* memcmp() */
+#include <stdlib.h>             /* random() */
 
 #include "gliv.h"
 #include "next_image.h"
@@ -439,6 +440,35 @@ void load_direction(gint dir)
     }
 }
 
+/* Load a randomly selected image from the list. */
+void load_random_image()
+{
+    gint nr;
+    const gchar *filename;
+
+    nr = random() % get_list_length();
+    filename = get_nth_filename(nr);
+    menu_load(filename);
+}
+
+/* Load the first image from the list. */
+void load_1st_image()
+{
+    const gchar *filename;
+
+    filename = get_nth_filename(0);
+    menu_load(filename);
+}
+
+/* Load the last image in the list. */
+void load_last_image()
+{
+    const gchar *filename;
+
+    filename = get_nth_filename(get_list_length() - 1);
+    menu_load(filename);
+}
+
 /*
  * After many images are opened we want to load
  * the next image but not the preloaded one.
@@ -619,8 +649,12 @@ void reload_changed_files(gpointer * stat_data)
     if (DIFFERENT(next))
         forget_image(&next_image);
 
-    if (now->current.present && DIFFERENT(current))
-        reload_current_image();
+    if (DIFFERENT(current)) {
+        if (now->current.present)
+            reload_current_image();
+        else
+            add_obsolete_node(current_image->node);
+    }
 
     g_free(before);
     g_free(now);
