@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /*******************
@@ -138,7 +138,7 @@ static GtkFileChooser *decorated_dialog(gboolean select_dir)
 
 static void open_images(gchar ** paths, gint nb)
 {
-    gint nb_inserted = insert_after_current(paths, nb, FALSE, FALSE);
+    gint nb_inserted = insert_after_current(paths, nb, FALSE, TRUE);
 
     new_images(nb_inserted);
 }
