@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /**********************
@@ -215,8 +215,6 @@ static void process_line(const gchar * line)
     /* res[0]: option name ; res[1]: value */
     res = g_strsplit(clean, "=", 2);
 
-    g_free(clean);
-
     if (res[0] != NULL && res[1] != NULL && res[2] == NULL) {
         /* No error during split. */
         opt = g_hash_table_lookup(table, res[0]);
@@ -236,9 +234,12 @@ static void process_line(const gchar * line)
                 value = (gint *) opt->option;
                 *value = (gint) g_strtod(res[1], NULL);
             }
-        }
-    }
+        } else
+            g_printerr(_("Unknown option in configuration file: %s\n"), res[0]);
+    } else
+        g_printerr(_("Parse error in configuration file: %s\n"), clean);
 
+    g_free(clean);
     g_strfreev(res);
 }
 
