@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /******************************************
@@ -54,6 +54,12 @@ gboolean toggle_scrollbars(void)
     return FALSE;
 }
 
+static void changed_scrollbars(void)
+{
+    gtk_adjustment_changed(gtk_range_get_adjustment(GTK_RANGE(hscroll)));
+    gtk_adjustment_changed(gtk_range_get_adjustment(GTK_RANGE(vscroll)));
+}
+
 /* Update a given scrollbar. */
 static void update_scroll(GtkScrollbar * scroll, gfloat min, gfloat max,
                           gfloat dim)
@@ -82,10 +88,8 @@ static void update_scroll(GtkScrollbar * scroll, gfloat min, gfloat max,
     /* The offset is actually computed with adj->lower and adj->upper. */
     adj->value = 0.0;
 
-    if (update_needed) {
-        gtk_adjustment_changed(adj);
-        gdk_window_process_updates(GTK_WIDGET(scroll)->window, FALSE);
-    }
+    if (update_needed)
+        do_later(G_PRIORITY_LOW, changed_scrollbars);
 }
 
 /* Update both scrollbars. */
