@@ -15,7 +15,7 @@
  *
  * See the COPYING file for license information.
  *
- * Guillaume Chazarain <guichaz@yahoo.fr>
+ * Guillaume Chazarain <guichaz@gmail.com>
  */
 
 /********************************************
@@ -41,11 +41,6 @@ void reset_timestamp(timestamp_t * ts)
     *ts = 0;
 }
 
-gboolean has_timestamp(timestamp_t ts)
-{
-    return ts != 0;
-}
-
 gboolean up_to_date(timestamp_t ts, timestamp_t req)
 {
     return req && ts > req;
