@@ -14,7 +14,7 @@ for d in $DECOMP_EXTS
     done
 done
 
-echo -n "'*:image:_files -/ -g \*.\(\#i\)\("
+echo -n "'*:images:_files -/ -g \*.\(\#i\)\("
 echo -n $EXTS | sed 's# #\\|#g'
 echo -n "\)'"
 echo
